@@ -27,7 +27,7 @@ def _parse_jenkins_json(request):
             # Seems bad that there's only 1 key, but press on
             return request.form
     else:
-        return request.form
+        return request.json
 
 
 @base.route("/notification/jenkins", methods=["POST"])
@@ -103,7 +103,7 @@ def github_notification():
                   "%s %s (%s): %s",
                   base_repo_name, number, html_url, action)
 
-    if action not in ("opened", "synchronize"):
+    if action not in ("opened", "reopened", "synchronize"):
         logging.debug("Ignored '%s' action." % action)
         return Response(status=204)
 
